@@ -25,7 +25,7 @@ def transfer_origin_database_dump():
             get_origin_database_dump(system.default_local_sync_path)
             system.check_target_configuration()
             put_origin_database_dump(system.default_local_sync_path)
-        elif mode.get_sync_mode() == mode.SyncMode.SYNC_REMOTE:
+        elif mode.get_sync_mode() == mode.SyncMode.SYNC_REMOTE or mode.get_sync_mode() == mode.SyncMode.SYNC_LOCAL:
             system.check_target_configuration()
         elif system.config['is_same_client']:
             utility.remove_origin_database_dump(True)
